jacinle.comm.cs
===============

.. automodule:: jacinle.comm.cs

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      ClientPipe
      ServerPipe
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      make_cs_pair
   
   

   
   
   








.. rubric:: Class ClientPipe
.. autoclass:: ClientPipe
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class ServerPipe
.. autoclass:: ServerPipe
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: make_cs_pair


